Groups | Search | Server Info | Keyboard shortcuts | Login | Register [http] [https] [nntp] [nntps]


Groups > linux.kernel > #1521632 > unrolled thread

[PATCH] [media] gp8psk-fe: add missing MODULE_foo() macros

Started byMauro Carvalho Chehab <mchehab@infradead.org>
First post2016-11-14 14:20 +0100
Last post2016-11-14 14:40 +0100
Articles 2 — 2 participants

Back to article view | Back to linux.kernel


Contents

  [PATCH] [media] gp8psk-fe: add missing MODULE_foo() macros Mauro Carvalho Chehab <mchehab@infradead.org> - 2016-11-14 14:20 +0100
    Re: [PATCH] [media] gp8psk-fe: add missing MODULE_foo() macros Paul Bolle <pebolle@tiscali.nl> - 2016-11-14 14:40 +0100

#1521632 — [PATCH] [media] gp8psk-fe: add missing MODULE_foo() macros

FromMauro Carvalho Chehab <mchehab@infradead.org>
Date2016-11-14 14:20 +0100
Subject[PATCH] [media] gp8psk-fe: add missing MODULE_foo() macros
Message-ID<sDpkZ-7tt-7@gated-at.bofh.it>
This file was converted to a separate module at commit
7a0786c19d65 ("gp8psk: Fix DVB frontend attach"), because
the DVB attach routines require it to work. However,
I forgot to copy the MODULE_foo() macros from the original
module, causing this warning:
	WARNING: modpost: missing MODULE_LICENSE() in drivers/media/dvb-frontends/gp8psk-fe.o

Reported-by: Stephen Rothwell <sfr@canb.auug.org.au>
Fixes: 7a0786c19d65 ("gp8psk: Fix DVB frontend attach")
Signed-off-by: Mauro Carvalho Chehab <mchehab@s-opensource.com>

diff --git a/drivers/media/dvb-frontends/gp8psk-fe.c b/drivers/media/dvb-frontends/gp8psk-fe.c
index be19afeed7a9..93f59bfea092 100644
--- a/drivers/media/dvb-frontends/gp8psk-fe.c
+++ b/drivers/media/dvb-frontends/gp8psk-fe.c
@@ -1,5 +1,5 @@
 /* DVB USB compliant Linux driver for the
  *  - GENPIX 8pks/qpsk/DCII USB2.0 DVB-S module
  *
  * Copyright (C) 2006,2007 Alan Nisota (alannisota@gmail.com)
  * Copyright (C) 2006,2007 Genpix Electronics (genpix@genpix-electronics.com)
@@ -8,11 +8,9 @@
  *
  * This module is based off the vp7045 and vp702x modules
  *
- *	This program is free software; you can redistribute it and/or modify it
- *	under the terms of the GNU General Public License as published by the Free
- *	Software Foundation, version 2.
- *
- * see Documentation/dvb/README.dvb-usb for more information
+ * This program is free software; you can redistribute it and/or modify it
+ * under the terms of the GNU General Public License as published by the Free
+ * Software Foundation, version 2.
  */
 
 #define pr_fmt(fmt) KBUILD_MODNAME ": " fmt
@@ -395,3 +393,8 @@ static struct dvb_frontend_ops gp8psk_fe_ops = {
 	.dishnetwork_send_legacy_command = gp8psk_fe_send_legacy_dish_cmd,
 	.enable_high_lnb_voltage = gp8psk_fe_enable_high_lnb_voltage
 };
+
+MODULE_AUTHOR("Alan Nisota <alannisota@gamil.com>");
+MODULE_DESCRIPTION("Frontend Driver for Genpix DVB-S");
+MODULE_VERSION("1.1");
+MODULE_LICENSE("GPL");
@@ -1,5 +1,5 @@
-/* DVB USB compliant Linux driver for the
- *  - GENPIX 8pks/qpsk/DCII USB2.0 DVB-S module
+/*
+ * Frontend driver for the GENPIX 8pks/qpsk/DCII USB2.0 DVB-S module
  *
  * Copyright (C) 2006,2007 Alan Nisota (alannisota@gmail.com)


Thanks,
Mauro

[toc] | [next] | [standalone]


#1521652

FromPaul Bolle <pebolle@tiscali.nl>
Date2016-11-14 14:40 +0100
Message-ID<sDpEm-7Av-41@gated-at.bofh.it>
In reply to#1521632
On Mon, 2016-11-14 at 11:14 -0200, Mauro Carvalho Chehab wrote:

> --- a/drivers/media/dvb-frontends/gp8psk-fe.c
> +++ b/drivers/media/dvb-frontends/gp8psk-fe.c

> + * This program is free software; you can redistribute it and/or modify it
> + * under the terms of the GNU General Public License as published by the Free
> + * Software Foundation, version 2.

> +MODULE_LICENSE("GPL");

Nit: according to the comments in include/linux/module.h the "ident" that
matches the license described at the top of this file is "GPL v2".


Paul Bolle

[toc] | [prev] | [standalone]


Back to top | Article view | linux.kernel


csiph-web